@@ -40,6 +40,8 @@ extern "C" {
 #ifdef _WIN32
 #	if defined(_M_IX86)
 #		define _LITTLE_ENDIAN
+#	elif defined(_M_AMD64)
+#		define _LITTLE_ENDIAN
 #	elif defined(_M_MRX000)
 #		define _LITTLE_ENDIAN
 #	elif defined(_M_ALPHA)
@@ -92,18 +94,6 @@ extern "C" {
 #endif
 #endif
 
-#ifdef SCO
-#   include <sys/types.h>
-#   include <sys/byteorder.h>
-#   if BYTE_ORDER == LITTLE_ENDIAN
-#   	define _LITTLE_ENDIAN
-#   elif BYTE_ORDER == BIG_ENDIAN
-#   	define _BIG_ENDIAN
-#   elif BYTE_ORDER == PDP_ENDIAN
-#   	define _PDP_ENDIAN
-#   endif
-#endif
-
 #ifdef AIX
 #   include <sys/machine.h>
 #   if BYTE_ORDER == LITTLE_ENDIAN
@@ -119,14 +109,6 @@ extern "C" {
 #   endif
 #endif
 
-#ifdef HPUX
-#	include <machine/param.h>
-#endif
-
-#ifdef _WIN16
-#	define	_LITTLE_ENDIAN
-#endif
-
 #ifdef OS2
 #	include <machine/endian.h>
 #endif
@@ -154,10 +136,11 @@ extern "C" {
 
 /** Check supported platform.
  */
-#if !defined(_WIN32)  && !defined(_WIN16) && !defined(OS2)     && \
-    !defined(LINUX)   && !defined(NETBSD) && !defined(SCO)     && \
-    !defined(AIX)     && !defined(HPUX)   && !defined(OPENBSD) && \
-    !defined(SOLARIS) && !defined(MACOSX) && !defined(FREEBSD)
+#if !defined(_WIN32)  && !defined(OS2)     && \
+    !defined(LINUX)   && !defined(NETBSD) && \
+    !defined(AIX)     && !defined(OPENBSD) && \
+    !defined(SOLARIS) && !defined(MACOSX) && !defined(FREEBSD) && \
+    !defined(DRAGONFLY)
 #	error "Target platform not specified !"
 #endif
 
